# UrbanDictionary-API

 This is an unofficial UrbanDictionary API.<br>

Code Example:<br>
```py
from urbandictionaryapi import UrbanDictionary

UrbanDictionary.search('word')
UrbanDictionary.author()
```